# Contributors

## Release 0.8.8
Many thanks to Steven Wijnen for his debugging, testing and help with the QP, constraints and FBCV3 implementation. This release supports his dcFBA/endPointFBA https://github.com/SystemsBioinformatics/dynamic-community-fba package.

## Release 0.8.4
Many thanks go to @willigot for their suggestions and code contributions.

## Release 0.8.2

## Release 0.8.1

Many thanks go to @jonrkarr and @willigot for their suggestions and code contributions.


(c) Brett G. Olivier, Amsterdam, 2021